.. _api.data:

====
Data
====

General
-------

.. autosummary::
    :toctree: api/

    prismstudio.get_data
    prismstudio.dataitems


Data Category
-------------

We show data in categories below.

.. toctree::
    :maxdepth: 2

    market
    financial
    estimate
    event
    company
    reference
    precalculated
    index_data
    transaction
    esg
    economics